package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusMountainFloodVillageEntity;
import com.zcloud.modules.kangzai.service.BusMountainFloodVillageService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 山洪灾害村基本信息表(BusMountainFloodVillage)表控制层
 * @Date 2025-06-09 10:14:59
 */
@Api(tags = "山洪灾害村基本信息表")
@RestController
@RequestMapping("busMountainFloodVillage")
public class BusMountainFloodVillageController extends AbstractController {

    @Autowired
    private BusMountainFloodVillageService busMountainFloodVillageService;

    @ApiOperation("山洪灾害村基本信息表-新增数据")
    @SysLog("山洪灾害村基本信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusMountainFloodVillageEntity param) {
        param.setCreator(getUserId());
        param.setOperator(getUserId());
        busMountainFloodVillageService.save(param);

        return R.ok();
    }

    @ApiOperation("山洪灾害村基本信息表-编辑数据")
    @SysLog("山洪灾害村基本信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusMountainFloodVillageEntity param) {
        param.setOperator(getUserId());
        busMountainFloodVillageService.updateById(param);

        return R.ok();
    }


    @ApiOperation("山洪灾害村基本信息表-删除数据")
    @SysLog("山洪灾害村基本信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusMountainFloodVillageEntity param) {
        busMountainFloodVillageService.delete(param.getMountainFloodVillageId(), getUserId());
        return R.ok();
    }

    @ApiOperation("山洪灾害村基本信息表-分页查询")
    @SysLog("山洪灾害村基本信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busMountainFloodVillageService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("山洪灾害村基本信息表-根据ID查详情")
    @SysLog("山洪灾害村基本信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusMountainFloodVillageEntity param) {
        BusMountainFloodVillageEntity busMountainFloodVillage = busMountainFloodVillageService.getById(param.getMountainFloodVillageId());
        return R.ok().put("busMountainFloodVillage", busMountainFloodVillage);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busMountainFloodVillageService.queryByFlexibleParams("is_delete", "0"));
    }
}
